/*
 * Copyright 2002-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.test.context.web;

import org.junit.Test;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.test.context.ContextConfiguration;

import static org.junit.Assert.*;

/**
 * @author Sam Brannen
 * @since 3.2
 */
@ContextConfiguration
public class BasicAnnotationConfigWacTests extends AbstractBasicWacTests {

	@Configuration
	static class Config {

		@Bean
		public String foo() {
			return "enigma";
		}

		@Bean
		public ServletContextAwareBean servletContextAwareBean() {
			return new ServletContextAwareBean();
		}
	}

	@Autowired
	protected ServletContextAwareBean servletContextAwareBean;

	@Test
	public void fooEnigmaAutowired() {
		assertEquals("enigma", foo);
	}

	@Test
	public void servletContextAwareBeanProcessed() {
		assertNotNull(servletContextAwareBean);
		assertNotNull(servletContextAwareBean.servletContext);
	}

}
